@@ -10,6 +10,8 @@ import os
 import datetime
 import time
 from colorama import *
+from web import *
+
 init(autoreset=True)
 print(f'[{time.ctime()}][main/Info] module colorama inited')
 print(f'[{time.ctime()}][main/Info] modules initlazed')
@@ -26,6 +28,7 @@ class window2(QtWidgets.QMainWindow,Ui_MainWindow2):
 
 
 
+
 class window(QtWidgets.QMainWindow,Ui_MainWindow):
     signal = pyqtSignal()
     def __init__(self):
@@ -210,16 +213,19 @@ class window(QtWidgets.QMainWindow,Ui_MainWindow):
         else:
 
             self.progressBar.setValue(v)
-
-from PyQt5.Qt import PYQT_VERSION_STR
-from PyQt5.QtCore import QT_VERSION_STR
-print(f'[{time.ctime()}][main/Info] backend library:PyQt5 version {PYQT_VERSION_STR} build {QT_VERSION_STR}')
-app = QtWidgets.QApplication(sys.argv)
-window = window()
-window.show()
-window2=window2()
-window.signal.connect(window2.show)
-sys.exit(app.exec_())
+if __name__ == '__main__':
+    from PyQt5.Qt import PYQT_VERSION_STR
+    from PyQt5.QtCore import QT_VERSION_STR
+    print(f'[{time.ctime()}][main/Info] backend library:PyQt5 version {PYQT_VERSION_STR} build on Qt {QT_VERSION_STR}')
+    app = QtWidgets.QApplication(sys.argv)
+    window = window()
+    window.show()
+    window2=window2()
+    window.signal.connect(window2.show)
+    sys.exit(app.exec_())
+else:
+    print(f'[{time.ctime()}][main/Info] now varbile "__name__"={__name__},run in web mode')
+    run('v0.6')
 
 
 
